@@ -12,7 +12,7 @@ See 'pdccolor.txt' for a rationale of how this works. */
 #define PACKED_RGB uint32_t
 
 #ifndef PACK_RGB
-   #define PACK_RGB( red, green, blue) ((red) | ((green)<<8) | ((PACKED_RGB)(blue) << 16))
+   #define PACK_RGB( red, green, blue) ((PACKED_RGB)(red) | ((PACKED_RGB)(green)<<8) | ((PACKED_RGB)(blue) << 16))
 #endif
 
 #include <curspriv.h>
@@ -188,7 +188,7 @@ void PDC_get_rgb_values( const chtype srcp,
     {
         if( !(SP->termattrs & A_BLINK))   /* convert 'blinking' to 'bold' */
             intensify_backgnd = TRUE;
-        else if( SP->blink_state)
+        else if( SP->blink_state & 1)
             reverse_colors ^= 1;
     }
     if( default_foreground)
