@@ -116,6 +116,12 @@ bool    PDC_touched_range( const WINDOW *win, const int y, int *firstch, int *la
 int     PDC_wscrl(WINDOW *win, const int top, const int bottom, int n);
 
 #ifdef PDC_WIDE
+#ifndef IS_LOW_SURROGATE         /* Microsoft(R) Windows redefines these */
+   #define IS_LOW_SURROGATE( c) ((c) >= 0xdc00 && (c) < 0xe000)
+   #define IS_SURROGATE( x)       ((x) >= 0xd800 && (x) < 0xe000)
+   #define IS_HIGH_SURROGATE( c) ((c) >= 0xd800 && (c) < 0xdc00)
+#endif
+
 int     PDC_mbtowc(wchar_t *, const char *, size_t);
 size_t  PDC_mbstowcs(wchar_t *, const char *, size_t);
 size_t  PDC_wcstombs(char *, const wchar_t *, size_t);
@@ -129,8 +135,10 @@ int PDC_expand_combined_characters( const cchar_t c, cchar_t *added);
 
 #ifdef PDCDEBUG
 # define PDC_LOG(x) if (SP && SP->dbfp) PDC_debug x
+# define PDC_LOG_F( flag, x) if (SP && SP->dbfp && (SP->trace_flags & (flag))) PDC_debug x
 #else
 # define PDC_LOG(x)
+# define PDC_LOG_F( flag, x)
 #endif
 
 /* Internal macros for attributes */
@@ -266,6 +274,7 @@ struct _screen
     WINDOW **window_list;
     unsigned trace_flags;
     bool want_trace_fflush;
+    bool ncurses_mouse;          /* map wheel events to button 4,5 presses */
     FILE *output_fd, *input_fd;
     struct _port_info *pinfo;
 };
