@@ -1,3 +1,4 @@
+
 /*
  * This is a test program for PDCurses. Originally by
  * John Burnell <johnb@kea.am.dsir.govt.nz>
@@ -14,7 +15,7 @@
 SysV) mouse functions in inputTest.  Otherwise,  the ncurses mouse
 interface will be used.       */
 
- #define CLASSIC_MOUSE_INTERFACE
+// #define CLASSIC_MOUSE_INTERFACE
 
 #if defined( CLASSIC_MOUSE_INTERFACE)
    #define BUTTON_MOVE_EVENTS (BUTTON1_MOVED | BUTTON2_MOVED | BUTTON3_MOVED \
@@ -192,9 +193,6 @@ static mmask_t parse_mouse_mask( const char *str)
          case 'M':
             test_mouse_mask |= REPORT_MOUSE_POSITION;
             break;
-         case 'W':
-            mouseinterval( atoi( str + 1));
-            break;
          }
       str++;
       if( event_ptr)
@@ -226,9 +224,28 @@ int main(int argc, char *argv[])
         if( argv[i][0] == '-')
             switch( argv[i][1])
             {
+                case 'd':
+                    {
+                        unsigned flags;
+
+                        if( 1 == sscanf( argv[i] + 2, "%x", &flags))
+                            curses_trace( flags);
+                    }
+                    break;
+                case 'i': case 'I':
+                    mouseinterval( atoi( argv[i] + 2));
+                    break;
                 case 'l': case 'L':
                     setlocale( LC_CTYPE, argv[i] + 2);
                     break;
+                case 's':
+                    {
+                        char tbuff[200];
+
+                        if( fgets( tbuff, sizeof( tbuff), stdin))
+                           printf( "Got a line\n%s", tbuff);
+                    }
+                    break;
 #ifdef __PDCURSESMOD__
                 case 'b': case 'B':
                     PDC_set_blink( TRUE);
@@ -1609,10 +1626,10 @@ void remap(int tmarg, const short *colors)
 
     for (i = 0; i < 8; i++)
     {
-        init_color(colors[i], i * 125, 0, i * 125);
+        init_color(colors[i], (short)( i * 125), 0, (short)( i * 125));
 
         if (COLORS >= 16)
-            init_color(colors[i] + 8, 0, i * 125, 0);
+            init_color((short)( colors[i] + 8), 0, (short)( i * 125), 0);
     }
 
     mvaddstr(tmarg + 19, 3, "Press any key to continue");
@@ -1768,31 +1785,33 @@ void gradient(int tmarg)
 
             if (!i || i == 3)
             {
-                init_color(cnum,    (i ? 0 : 1000), oval, oval);
-                init_color(cnum + 1,(i ? 1000 : 0), reverse, 0);
+                init_color(cnum,  (short)( i ? 0 : 1000), oval, oval);
+                cnum++;
+                init_color( cnum, (short)( i ? 1000 : 0), reverse, 0);
             }
             else if (i == 1 || i == 4)
             {
-                init_color(cnum,     (i == 4 ? 1000 : 0), 0, reverse);
-                init_color(cnum + 1, (i == 4 ? 0 : 1000), reverse, 0);
+                init_color( cnum, (short)( i == 4 ? 1000 : 0), 0, reverse);
+                cnum++;
+                init_color( cnum, (short)( i == 4 ? 0 : 1000), reverse, 0);
             }
             else if( i == 2 || i == 5)
             {
-                init_color(cnum,     reverse, (i == 2 ? 1000 : 0), reverse);
+                init_color(cnum, reverse, (short)( i == 2 ? 1000 : 0), reverse);
+                cnum++;
                 if( i == 2)
-                   init_color(cnum + 1, reverse, 0, oval);
+                   init_color(cnum, reverse, 0, oval);
                 else
-                   init_color(cnum + 1, oval, oval, oval);
+                   init_color(cnum, oval, oval, oval);
             }
-            init_pair(pnum, cnum, cnum + 1);
+            init_pair(pnum, (short)( cnum - 1), cnum);
+            cnum++;
             attrset(COLOR_PAIR(pnum));
             if (i == 2)
                 attron(A_UNDERLINE);
             else
                 attroff(A_UNDERLINE);
             addch(output_text[i][j]);
-
-            cnum += 2;
             pnum++;
         }
     }
@@ -1852,9 +1871,9 @@ void colorTest(WINDOW *win)
 
     for (i = 0; i < 8; i++)
     {
-        init_pair((short)i + 4, colors[i], COLOR_BLACK);
+        init_pair((short)( i + 4), colors[i], COLOR_BLACK);
         if (widecol)
-            init_pair((short)i + 12, colors[i] + 8, COLOR_BLACK);
+            init_pair((short)( i + 12), (short)( colors[i] + 8), COLOR_BLACK);
 
         mvaddstr(tmarg + i + 5, col1, colornames[i]);
 
@@ -1909,7 +1928,7 @@ void wideTest(WINDOW *win)
     addwstr(tmp);
     addstr("\n\n\n Hex:\n\n ");
 
-    for (i = 0; i < wcslen(tmp); i++)
+    for (i = 0; tmp[i]; i++)
     {
         printw("%04x ", tmp[i]);
         addnwstr(tmp + i, 1);
