@@ -41,7 +41,6 @@ void release_framebuffer(struct framebuffer *fb)
         /* Try to become master again, else we can't set CRTC. Then the current master needs to reset everything. */
         const int err = drmSetMaster(fb->fd);
 
-//      assert( !err);
         if (fb->crtc) {
             /* Set back to original frame buffer */
             drmModeSetCrtc(fb->fd, fb->crtc->crtc_id, fb->crtc->buffer_id, 0, 0, &fb->connector->connector_id, 1, fb->resolution);
@@ -74,23 +73,36 @@ void release_framebuffer(struct framebuffer *fb)
 
 static int n_connectors;
 
-int get_framebuffer(const char *dri_device, const int connector_num, struct framebuffer *fb)
+int get_framebuffer( const int connector_num, struct framebuffer *fb)
 {
     int err;
-    int i, fd, j;
+    int i, fd = -1, j;
     drmModeResPtr res;
     drmModeEncoderPtr encoder = 0;
     drmModeConnectorPtr connector = 0;
+    drmModeModeInfoPtr resolution = 0;
+    struct drm_mode_map_dumb mreq;
 
-    /* Open the dri device /dev/dri/cardX */
-    fd = open(dri_device, O_RDWR);
+    /* Open the dri device /dev/dri/cardX.  That'll usually be card0, */
+    /* but I've seen a card1 case;  there are no guarantees */
+    for( i = 0; fd < 0 && i < 10; i++)
+    {
+        char filename[30];
+
+        snprintf( filename, sizeof( filename), "/dev/dri/card%d", i);
+        fd = open( filename, O_RDWR);
+    }
     if (fd < 0)
+    {
+        perror( "Couldn't open the video card device");
         return FRAMEBUFFER_COULD_NOT_OPEN_DEVICE;
+    }
 
     /* Get the resources of the DRM device (connectors, encoders, etc.)*/
     res = drmModeGetResources(fd);
     if (!res) {
         close( fd);
+        fprintf( stderr, "Couldn't get resources\n");
         return FRAMEBUFFER_COULD_NOT_GET_RESOURCES;
     }
 
@@ -123,11 +135,13 @@ int get_framebuffer(const char *dri_device, const int connector_num, struct fram
     drmModeFreeResources( res);
 
     if (!connector)
+    {
+        fprintf( stderr, "Couldn't find connector\n");
         return FRAMEBUFFER_COULD_NOT_FIND_CONNECTOR;
+    }
 
     /* Get the preferred resolution */
-    drmModeModeInfoPtr resolution = 0;
-    for (int i = 0; i < connector->count_modes; i++) {
+    for( i = 0; i < connector->count_modes; i++) {
             resolution = &connector->modes[i];
             if (resolution->type & DRM_MODE_TYPE_PREFERRED)
                     break;
@@ -165,8 +179,6 @@ int get_framebuffer(const char *dri_device, const int connector_num, struct fram
     /* Get the crtc settings */
     fb->crtc = drmModeGetCrtc(fd, encoder->crtc_id);
 
-    struct drm_mode_map_dumb mreq;
-
     memset(&mreq, 0, sizeof(mreq));
     mreq.handle = fb->dumb_framebuffer.handle;
 
@@ -196,8 +208,10 @@ cleanup:
 
 
     if (err)
+    {
+        fprintf( stderr, "Error %d in get_framebuffer( )\n", err);
         release_framebuffer(fb);
-
+    }
     return err;
 }
 
@@ -206,11 +220,11 @@ cleanup:
 static struct framebuffer _drm_framebuffer;
 int can_set_master;
 
-static int init_drm( const char *dri_device, const int connector_num)
+static int init_drm( const int connector_num)
 {
     int err, rval;
 
-    rval = get_framebuffer( dri_device, connector_num, &_drm_framebuffer);
+    rval = get_framebuffer( connector_num, &_drm_framebuffer);
     if( !rval)
     {
         PDC_fb.framebuf = _drm_framebuffer.data;
@@ -224,8 +238,11 @@ static int init_drm( const char *dri_device, const int connector_num)
         err = drmModeSetCrtc( _drm_framebuffer.fd, _drm_framebuffer.crtc->crtc_id,
                       0, 0, 0, NULL, 0, NULL);
         if( err)
+        {
+           fprintf( stderr, "Can't set CRTC\n");
+           drmError( err, "SetCrtc (1)");
            return( -1);
-        assert( !err);
+        }
         err = drmModeSetCrtc( _drm_framebuffer.fd, _drm_framebuffer.crtc->crtc_id,
                      _drm_framebuffer.buffer_id, 0, 0,
                      &_drm_framebuffer.connector->connector_id, 1,
