@@ -100,23 +100,24 @@ addch
    All functions return OK on success and ERR on error.
 
 ### Portability
-                             X/Open  ncurses  NetBSD
-    addch                       Y       Y       Y
-    waddch                      Y       Y       Y
-    mvaddch                     Y       Y       Y
-    mvwaddch                    Y       Y       Y
-    echochar                    Y       Y       Y
-    wechochar                   Y       Y       Y
-    add_wch                     Y       Y       Y
-    wadd_wch                    Y       Y       Y
-    mvadd_wch                   Y       Y       Y
-    mvwadd_wch                  Y       Y       Y
-    echo_wchar                  Y       Y       Y
-    wecho_wchar                 Y       Y       Y
-    addrawch                    -       -       -
-    waddrawch                   -       -       -
-    mvaddrawch                  -       -       -
-    mvwaddrawch                 -       -       -
+   Function              | X/Open | ncurses | NetBSD
+   :---------------------|:------:|:-------:|:------:
+   addch                 |    Y   |    Y    |   Y
+   waddch                |    Y   |    Y    |   Y
+   mvaddch               |    Y   |    Y    |   Y
+   mvwaddch              |    Y   |    Y    |   Y
+   echochar              |    Y   |    Y    |   Y
+   wechochar             |    Y   |    Y    |   Y
+   add_wch               |    Y   |    Y    |   Y
+   wadd_wch              |    Y   |    Y    |   Y
+   mvadd_wch             |    Y   |    Y    |   Y
+   mvwadd_wch            |    Y   |    Y    |   Y
+   echo_wchar            |    Y   |    Y    |   Y
+   wecho_wchar           |    Y   |    Y    |   Y
+   addrawch              |    -   |    -    |   -
+   waddrawch             |    -   |    -    |   -
+   mvaddrawch            |    -   |    -    |   -
+   mvwaddrawch           |    -   |    -    |   -
 
 **man-end****************************************************************/
 
@@ -482,9 +483,6 @@ int PDC_find_combined_char_idx( const cchar_t root, const cchar_t added)
     return( i);
 }
 
-#define IS_LOW_SURROGATE( c) ((c) >= 0xdc00 && (c) < 0xe000)
-#define IS_HIGH_SURROGATE( c) ((c) >= 0xd800 && (c) < 0xdc00)
-
 int PDC_expand_combined_characters( const cchar_t c, cchar_t *added)
 {
     if( !c)    /* flag to free up memory */
@@ -512,7 +510,7 @@ int waddch( WINDOW *win, const chtype ch)
     chtype text, attr;
     bool xlat;
 
-    PDC_LOG(("waddch() - called: win=%p ch=%x (text=%c attr=0x%x)\n",
+    PDC_LOG_F( TRACE_VIRTPUT, ("waddch() - called: win=%p ch=%x (text=%c attr=0x%x)\n",
              win, ch, ch & A_CHARTEXT, ch & A_ATTRIBUTES));
 
     assert( SP);
@@ -701,14 +699,14 @@ int waddch( WINDOW *win, const chtype ch)
 
 int addch(const chtype ch)
 {
-    PDC_LOG(("addch() - called: ch=%x\n", ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("addch() - called: ch=%x\n", ch));
 
     return waddch(stdscr, ch);
 }
 
 int mvaddch(int y, int x, const chtype ch)
 {
-    PDC_LOG(("mvaddch() - called: y=%d x=%d ch=%x\n", y, x, ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("mvaddch() - called: y=%d x=%d ch=%x\n", y, x, ch));
 
     if (move(y,x) == ERR)
         return ERR;
@@ -718,7 +716,7 @@ int mvaddch(int y, int x, const chtype ch)
 
 int mvwaddch(WINDOW *win, int y, int x, const chtype ch)
 {
-    PDC_LOG(("mvwaddch() - called: win=%p y=%d x=%d ch=%d\n", win, y, x, ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("mvwaddch() - called: win=%p y=%d x=%d ch=%d\n", win, y, x, ch));
 
     if (wmove(win, y, x) == ERR)
         return ERR;
@@ -728,14 +726,14 @@ int mvwaddch(WINDOW *win, int y, int x, const chtype ch)
 
 int echochar(const chtype ch)
 {
-    PDC_LOG(("echochar() - called: ch=%x\n", ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("echochar() - called: ch=%x\n", ch));
 
     return wechochar(stdscr, ch);
 }
 
 int wechochar(WINDOW *win, const chtype ch)
 {
-    PDC_LOG(("wechochar() - called: win=%p ch=%x\n", win, ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("wechochar() - called: win=%p ch=%x\n", win, ch));
 
     if (waddch(win, ch) == ERR)
         return ERR;
@@ -745,7 +743,7 @@ int wechochar(WINDOW *win, const chtype ch)
 
 int waddrawch(WINDOW *win, chtype ch)
 {
-    PDC_LOG(("waddrawch() - called: win=%p ch=%x (text=%c attr=0x%x)\n",
+    PDC_LOG_F( TRACE_VIRTPUT, ("waddrawch() - called: win=%p ch=%x (text=%c attr=0x%x)\n",
              win, ch, ch & A_CHARTEXT, ch & A_ATTRIBUTES));
 
     if ((ch & A_CHARTEXT) < ' ' || (ch & A_CHARTEXT) == 0x7f)
@@ -756,14 +754,14 @@ int waddrawch(WINDOW *win, chtype ch)
 
 int addrawch(chtype ch)
 {
-    PDC_LOG(("addrawch() - called: ch=%x\n", ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("addrawch() - called: ch=%x\n", ch));
 
     return waddrawch(stdscr, ch);
 }
 
 int mvaddrawch(int y, int x, chtype ch)
 {
-    PDC_LOG(("mvaddrawch() - called: y=%d x=%d ch=%d\n", y, x, ch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("mvaddrawch() - called: y=%d x=%d ch=%d\n", y, x, ch));
 
     if (move(y, x) == ERR)
         return ERR;
@@ -773,7 +771,7 @@ int mvaddrawch(int y, int x, chtype ch)
 
 int mvwaddrawch(WINDOW *win, int y, int x, chtype ch)
 {
-    PDC_LOG(("mvwaddrawch() - called: win=%p y=%d x=%d ch=%d\n",
+    PDC_LOG_F( TRACE_VIRTPUT, ("mvwaddrawch() - called: win=%p y=%d x=%d ch=%d\n",
              win, y, x, ch));
 
     if (wmove(win, y, x) == ERR)
@@ -785,7 +783,7 @@ int mvwaddrawch(WINDOW *win, int y, int x, chtype ch)
 #ifdef PDC_WIDE
 int wadd_wch(WINDOW *win, const cchar_t *wch)
 {
-    PDC_LOG(("wadd_wch() - called: win=%p wch=%x\n", win, *wch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("wadd_wch() - called: win=%p wch=%x\n", win, *wch));
 
     assert( wch);
     return wch ? waddch(win, *wch) : ERR;
@@ -793,7 +791,7 @@ int wadd_wch(WINDOW *win, const cchar_t *wch)
 
 int add_wch(const cchar_t *wch)
 {
-    PDC_LOG(("add_wch() - called: wch=%x\n", *wch));
+    PDC_LOG_F( TRACE_VIRTPUT, ("add_wch() - called: wch=%x\n", *wch));
 
     return wadd_wch(stdscr, wch);
 }
