@@ -77,19 +77,20 @@ getch
    character or function key token.
 
 ### Portability
-                             X/Open  ncurses  NetBSD
-    getch                       Y       Y       Y
-    wgetch                      Y       Y       Y
-    mvgetch                     Y       Y       Y
-    mvwgetch                    Y       Y       Y
-    ungetch                     Y       Y       Y
-    flushinp                    Y       Y       Y
-    get_wch                     Y       Y       Y
-    wget_wch                    Y       Y       Y
-    mvget_wch                   Y       Y       Y
-    mvwget_wch                  Y       Y       Y
-    unget_wch                   Y       Y       Y
-    PDC_get_key_modifiers       -       -       -
+   Function              | X/Open | ncurses | NetBSD
+   :---------------------|:------:|:-------:|:------:
+   getch                 |    Y   |    Y    |   Y
+   wgetch                |    Y   |    Y    |   Y
+   mvgetch               |    Y   |    Y    |   Y
+   mvwgetch              |    Y   |    Y    |   Y
+   ungetch               |    Y   |    Y    |   Y
+   flushinp              |    Y   |    Y    |   Y
+   get_wch               |    Y   |    Y    |   Y
+   wget_wch              |    Y   |    Y    |   Y
+   mvget_wch             |    Y   |    Y    |   Y
+   mvwget_wch            |    Y   |    Y    |   Y
+   unget_wch             |    Y   |    Y    |   Y
+   PDC_get_key_modifiers |    -   |    -    |   -
 
 **man-end****************************************************************/
 
@@ -646,13 +647,11 @@ static int _raw_wgetch_no_surrogate_pairs( WINDOW *win)
     }
 }
 
-#define IS_HIGH_SURROGATE( x)  ((x) >= 0xd800 && (x) < 0xdc00)
-#define IS_LOW_SURROGATE( x)   ((x) >= 0xdc00 && (x) < 0xe000)
-
 static int _raw_wgetch( WINDOW *win)
 {
    int rval = _raw_wgetch_no_surrogate_pairs( win);
 
+#ifdef PDC_WIDE
    if( IS_HIGH_SURROGATE( rval))
       {
       const int c = _raw_wgetch_no_surrogate_pairs( win);
@@ -660,6 +659,7 @@ static int _raw_wgetch( WINDOW *win)
       if( IS_LOW_SURROGATE( c))
          rval = ((rval - 0xd800) << 10) + 0x10000 + c - 0xdc00;
       }
+#endif
    return( rval);
 }
 
@@ -758,9 +758,11 @@ int wgetch(WINDOW *win)
         if( rval != ERR && (rval < 0 || rval > 127)
                   && !PDC_is_function_key( rval))
         {
-            wchar_t c = (wchar_t)rval;
+            wchar_t c[2];
 
-            n_buff = PDC_wcstombs( (char *)buffered, &c, 1);
+            c[0] = (wchar_t)rval;
+            c[1] = L'\0';
+            n_buff = PDC_wcstombs( (char *)buffered, c, sizeof( buffered));
             if( (int)n_buff <= 0)
             {
                 n_buff = 0;
