@@ -119,21 +119,22 @@ mouse
    current platform.
 
 ### Portability
-                             X/Open  ncurses  NetBSD
-    mouse_set                   -       -       -
-    mouse_on                    -       -       -
-    mouse_off                   -       -       -
-    request_mouse_pos           -       -       -
-    wmouse_position             -       -       -
-    getmouse                    -       *       -
-    mouseinterval               -       Y       -
-    wenclose                    -       Y       -
-    wmouse_trafo                -       Y       -
-    mouse_trafo                 -       Y       -
-    mousemask                   -       Y       -
-    nc_getmouse                 -       *       -
-    ungetmouse                  -       Y       -
-    has_mouse                   -       Y       -
+   Function              | X/Open | ncurses | NetBSD
+   :---------------------|:------:|:-------:|:------:
+   mouse_set             |    -   |    -    |   -
+   mouse_on              |    -   |    -    |   -
+   mouse_off             |    -   |    -    |   -
+   request_mouse_pos     |    -   |    -    |   -
+   wmouse_position       |    -   |    -    |   -
+   getmouse              |    -   |    *    |   -
+   mouseinterval         |    -   |    Y    |   -
+   wenclose              |    -   |    Y    |   -
+   wmouse_trafo          |    -   |    Y    |   -
+   mouse_trafo           |    -   |    Y    |   -
+   mousemask             |    -   |    Y    |   -
+   nc_getmouse           |    -   |    *    |   -
+   ungetmouse            |    -   |    Y    |   -
+   has_mouse             |    -   |    Y    |   -
 
     * See above, under Description
 
@@ -320,6 +321,17 @@ mmask_t mousemask(mmask_t mask, mmask_t *oldmask)
     return SP->_trap_mbe;
 }
 
+/* For full compatibility with the ncurses mouse interface,  we need
+to account for the fact that ncurses maps wheel-up to a button4 press
+and wheel-down to a button5 press.  It lacks PDCursesMod's separate
+wheel scroll event flag.        */
+
+mmask_t nc_mousemask(mmask_t mask, mmask_t *oldmask)
+{
+    SP->ncurses_mouse = TRUE;
+    return( mousemask( mask, oldmask));
+}
+
 int nc_getmouse(MEVENT *event)
 {
     int i;
@@ -362,12 +374,12 @@ int nc_getmouse(MEVENT *event)
         }
     }
 
-    if (MOUSE_WHEEL_UP)
+    if (MOUSE_WHEEL_UP || (Mouse_status.changes & 0x200))
         bstate |= BUTTON4_PRESSED;
-    else if (MOUSE_WHEEL_DOWN)
+    else if (MOUSE_WHEEL_DOWN || (Mouse_status.changes & 0x400))
         bstate |= BUTTON5_PRESSED;
 
-    for( i = 0; i < 3; i++)
+    for( i = 0; i < 5; i++)
     {
        if( Mouse_status.button[i] & PDC_BUTTON_SHIFT)
            bstate |= BUTTON_MODIFIER_SHIFT;
