@@ -1,4 +1,8 @@
-#define USE_UNICODE_ACS_CHARS 1
+#ifdef DOS
+   #define USE_UNICODE_ACS_CHARS 0
+#else
+   #define USE_UNICODE_ACS_CHARS 1
+#endif
 
 #include <wchar.h>
 #include <assert.h>
@@ -12,8 +16,6 @@
     #include <unistd.h>
 #endif
 
-#define USE_UNICODE_ACS_CHARS 1
-
 #include "curspriv.h"
 #include "pdcvt.h"
 #include "../common/acs_defs.h"
@@ -135,6 +137,24 @@ void PDC_gotoyx(int y, int x)
 
 #ifdef USING_COMBINING_CHARACTER_SCHEME
    int PDC_expand_combined_characters( const cchar_t c, cchar_t *added);  /* addch.c */
+
+static size_t _unpack_combined_character( wchar_t *obuff, const size_t buffsize,
+                                       const cchar_t ch)
+{
+    cchar_t root, newchar;
+    size_t rval = 1;
+
+    root = ch;
+    while( rval < buffsize && (root = PDC_expand_combined_characters( root,
+                       &newchar)) > MAX_UNICODE)
+       obuff[rval++] = (wchar_t)newchar;
+    obuff[0] = (wchar_t)root;
+    if( rval < buffsize)
+       obuff[rval++] = (wchar_t)newchar;
+    assert( rval < buffsize);
+    assert( rval > 1);
+    return( rval);
+}
 #endif
 
 static void color_string( char *otext, const PACKED_RGB rgb)
@@ -248,6 +268,10 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
     assert( lineno < SP->lines);
     assert( len > 0);
     assert( len < MAX_PACKET_LEN);
+#ifdef DOS           /* can't write to last cell at lower right */
+    if( lineno == SP->lines - 1 && len == SP->cols - x)
+        len--;
+#endif
     PDC_gotoyx( lineno, x);
     if( force_reset_all_attribs || (!x && !lineno))
     {
@@ -281,8 +305,10 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
           strcat( obuff, (*srcp & A_UNDERLINE) ? UNDERLINE_ON : UNDERLINE_OFF);
        if( changes & A_ITALIC)
           strcat( obuff, (*srcp & A_ITALIC) ? ITALIC_ON : ITALIC_OFF);
+#ifndef DOS
        if( changes & A_REVERSE)
           strcat( obuff, REVERSE_ON);
+#endif
 #ifndef _WIN32                /* MS doesn't support strikeout text */
        if( changes & A_STRIKEOUT)
           strcat( obuff, STRIKEOUT_ON);
@@ -290,43 +316,49 @@ void PDC_transform_line(int lineno, int x, int len, const chtype *srcp)
        if( SP->termattrs & changes & A_BLINK)
           strcat( obuff, (*srcp & A_BLINK) ? BLINK_ON : BLINK_OFF);
        if( changes & (A_COLOR | A_STANDOUT | A_BLINK | A_REVERSE))
+#ifdef DOS
+          reset_color( obuff + strlen( obuff), *srcp);
+#else
           reset_color( obuff + strlen( obuff), *srcp & ~A_REVERSE);
+#endif
        PDC_puts_to_stdout( obuff);
 #ifdef USING_COMBINING_CHARACTER_SCHEME
-       if( ch > (int)MAX_UNICODE)      /* chars & fullwidth supported */
+       if( ch > (int)MAX_UNICODE)      /* combining char sequence */
        {
-           cchar_t root, newchar;
+           wchar_t unpacked[10];
+           size_t i, n_wchars = _unpack_combined_character( unpacked, 10, ch);
 
-           root = ch;
-           while( (root = PDC_expand_combined_characters( root,
-                              &newchar)) > MAX_UNICODE)
-               ;
-           bytes_out = PDC_wc_to_utf8( obuff, (wchar_t)root);
-           root = ch;
-           while( (root = PDC_expand_combined_characters( root,
-                              &newchar)) > MAX_UNICODE)
-               {
-               bytes_out += PDC_wc_to_utf8( obuff + bytes_out, (wchar_t)newchar);
+           for( i = bytes_out = 0; i < n_wchars; i++)
+           {
+               bytes_out += PDC_wc_to_utf8( obuff + bytes_out, (wchar_t)unpacked[i]);
                if( bytes_out > OBUFF_SIZE - 6)
                   {
                   put_to_stdout( obuff, bytes_out);
                   bytes_out = 0;
                   }
-               }
-           bytes_out += PDC_wc_to_utf8( obuff + bytes_out, (wchar_t)newchar);
+           }
        }
        else if( ch < (int)MAX_UNICODE)
 #endif
        {
+#ifdef DOS
+           bytes_out = 1;
+           *obuff = (char)ch;
+#else
            bytes_out = PDC_wc_to_utf8( obuff, (wchar_t)ch);
+#endif
            while( count < len && !((srcp[0] ^ srcp[count]) & ~A_CHARTEXT)
                         && (ch = (srcp[count] & A_CHARTEXT)) < (int)MAX_UNICODE)
            {
                if( _is_altcharset( srcp[count]))
                   ch = (int)acs_map[ch & 0x7f];
+#ifdef DOS
+               obuff[bytes_out++] = (char)ch;
+#else
                if( ch < (int)' ' || (ch >= 0x80 && ch <= 0x9f))
                   ch = ' ';
                bytes_out += PDC_wc_to_utf8( obuff + bytes_out, (wchar_t)ch);
+#endif
                if( bytes_out > OBUFF_SIZE - 6)
                   {
                   put_to_stdout( obuff, bytes_out);
