@@ -1,4 +1,3 @@
-
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -15,12 +14,16 @@
 #include "pdcvt.h"
 #include "../common/mouse.c"
 
-#if defined( __BORLANDC__) || defined( DOS)
+#if defined( __BORLANDC__)
    #define WINDOWS_VERSION_OF_KBHIT kbhit
 #else
    #define WINDOWS_VERSION_OF_KBHIT _kbhit
 #endif
 
+#ifdef __DMC__
+   int dmc_getch( void);         /* see 'getch2.c' */
+#endif
+
 /* Modified from the accepted answer at
 
 https://stackoverflow.com/questions/33025599/move-the-cursor-in-a-c-program
@@ -49,6 +52,9 @@ static bool check_key( int *c)
     if( PDC_resize_occurred)
        return( TRUE);
 
+#ifdef HAVE_MOUSE
+    _check_mouse( );
+#endif
 #ifdef LINUX_FRAMEBUFFER_PORT
     PDC_check_for_blinking( );
 #endif
@@ -78,7 +84,11 @@ static bool check_key( int *c)
        {
        rval = TRUE;
        if( c)
+#ifdef __DMC__
+          *c = dmc_getch( );         /* see 'getch2.c' */
+#else
           *c = _getch( );
+#endif
        }
     else
        rval = FALSE;
@@ -97,9 +107,9 @@ void PDC_flushinp( void)
 {
    int thrown_away_char;
 
+   _mlist_count = 0;
    while( check_key( &thrown_away_char))
       ;
-   _mlist_count = 0;
 }
 
 #ifdef USE_CONIO
@@ -499,7 +509,8 @@ int PDC_get_key( void)
                }
             else                 /* SGR mouse encoding */
                {
-               int n_fields, n_bytes;
+               int n_fields;
+               int n_bytes;
                char tbuff[MAX_COUNT];
 
                assert( c[1] == '<');
@@ -511,25 +522,28 @@ int PDC_get_key( void)
                assert( n_fields == 3);
                assert( c[count] == 'M' || c[count] == 'm');
                assert( n_bytes == count - 2);
-               event_type = ((c[count] == 'm') ? BUTTON_RELEASED : BUTTON_PRESSED);
                button = idx & 3;
-#ifdef __HAIKU__
-               if( !release)
+               if( 3 == n_fields)
                   {
-                  if( button == 3 || (held >> button) & 1)
-                     idx |= 0x40;         /* it's actually a mouse movement */
-                  }
-               else if( button < 3)
-                  held &= ~(1 << button);
-               idx &= ~0x20;
+                  event_type = ((c[count] == 'm') ? BUTTON_RELEASED : BUTTON_PRESSED);
+#ifdef __HAIKU__
+                  if( !release)
+                     {
+                     if( button == 3 || (held >> button) & 1)
+                        idx |= 0x40;         /* it's actually a mouse movement */
+                     }
+                  else if( button < 3)
+                     held &= ~(1 << button);
+                  idx &= ~0x20;
 #else
-               if( idx & 0x40)            /* (SGR) wheel mouse event; */
-                  idx |= 0x20;            /* requires this bit set in 'traditional' encoding */
-               else if( idx & 0x20)       /* (SGR) mouse move event sets a different bit */
-                  idx ^= 0x60;            /* in the traditional encoding */
+                  if( idx & 0x40)            /* (SGR) wheel mouse event; */
+                     idx |= 0x20;            /* requires this bit set in 'traditional' encoding */
+                  else if( idx & 0x20)       /* (SGR) mouse move event sets a different bit */
+                     idx ^= 0x60;            /* in the traditional encoding */
 #endif
-               x--;
-               y--;
+                  x--;
+                  y--;
+                  }
                }
             if( idx & 4)
                flags |= BUTTON_SHIFT;
@@ -626,7 +640,11 @@ int PDC_get_key( void)
          if( shifted_keys[rval >> 4] & (1 << (rval & 0xf)))
             modifiers = SHF;
          }
+#if defined( LINUX_FRAMEBUFFER_PORT) && defined( HAVE_MOUSE)
+      SP->key_modifiers = _key_modifiers;
+#else
       SP->key_modifiers = modifiers;
+#endif
       }
    if( rval > 0 && rval == PDC_get_function_key( FUNCTION_KEY_ABORT))
       raise( SIGINT);
@@ -660,7 +678,6 @@ int PDC_mouse_set( void)
 {
 #ifndef LINUX_FRAMEBUFFER_PORT
    if( !PDC_is_ansi)
-#endif
       {
       static int curr_tracking_state = -1;
       int tracking_state;
@@ -697,6 +714,7 @@ int PDC_mouse_set( void)
          PDC_doupdate( );
          }
       }
+#endif      /* #ifndef LINUX_FRAMEBUFFER_PORT */
    return(  OK);
 }
 
